==> selenium-selenium-4.21.0.gh.tar.gz: selenium-selenium-4.21.0/rb/spec/integration/selenium/webdriver/edge/options_spec.rb <==
# frozen_string_literal: true

# Licensed to the Software Freedom Conservancy (SFC) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The SFC licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

require_relative '../spec_helper'

module Selenium
  module WebDriver
    module Edge
      describe Options, exclusive: {browser: :edge} do
        it 'passes emulated device correctly' do
          reset_driver!(emulation: {device_name: 'Nexus 5'}) do |driver|
            ua = driver.execute_script 'return window.navigator.userAgent'
            expect(ua).to include('Nexus 5')
          end
        end

        it 'passes emulated user agent correctly' do
          reset_driver!(emulation: {user_agent: 'foo;bar'}) do |driver|
            ua = driver.execute_script 'return window.navigator.userAgent'
            expect(ua).to eq('foo;bar')
          end
        end

        it 'passes args correctly' do
          reset_driver!(args: ['--user-agent=foo;bar']) do |driver|
            ua = driver.execute_script 'return window.navigator.userAgent'
            expect(ua).to eq('foo;bar')
          end
        end
      end
    end # Edge
  end # WebDriver
end # Selenium

==> selenium-selenium-4.25.0.gh.tar.gz: selenium-selenium-4.25.0/rb/spec/integration/selenium/webdriver/edge/options_spec.rb <==
# frozen_string_literal: true

# Licensed to the Software Freedom Conservancy (SFC) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The SFC licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

require_relative '../spec_helper'

module Selenium
  module WebDriver
    module Edge
      describe Options, exclusive: [{bidi: false, reason: 'Not yet implemented with BiDi'}, {browser: :edge}] do
        it 'passes emulated device correctly' do
          reset_driver!(emulation: {device_name: 'Nexus 5'}) do |driver|
            ua = driver.execute_script 'return window.navigator.userAgent'
            expect(ua).to include('Nexus 5')
          end
        end

        it 'passes emulated user agent correctly' do
          reset_driver!(emulation: {user_agent: 'foo;bar'}) do |driver|
            ua = driver.execute_script 'return window.navigator.userAgent'
            expect(ua).to eq('foo;bar')
          end
        end

        it 'passes args correctly' do
          reset_driver!(args: ['--user-agent=foo;bar']) do |driver|
            ua = driver.execute_script 'return window.navigator.userAgent'
            expect(ua).to eq('foo;bar')
          end
        end
      end
    end # Edge
  end # WebDriver
end # Selenium
